/************************************************************************************
coordinatetransformationirs
Copyright (c) 2010, International Rescue System Institute
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD license.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/

#ifndef TESTINPUT_H
#define TESTINPUT_H

#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>
#include <rtm/idl/BasicDataTypeSkel.h>

// Service implementation headers
// <rtc-template block="service_impl_h">

// </rtc-template>


//-- [ヘッダファイル] ---------------------------------------------------------------------------//
#include "input.h"											// inputヘッダファイル読み込み
#include <math.h>											// mathヘッダファイル読み込み
//-----------------------------------------------------------------------------------------------//


//-- [置換] -------------------------------------------------------------------------------------//
#define DEBUG_CONFIGURATION										// DEBUG定義 [デバッグ用]
//-----------------------------------------------------------------------------------------------//


// Service Consumer stub headers
// <rtc-template block="consumer_stub_h">
#include "intellirobotStub.h"

// </rtc-template>

using namespace RTC;

class TestInput
  : public RTC::DataFlowComponentBase
{
 public:
  TestInput(RTC::Manager* manager);
  ~TestInput();

	// The initialize action (on CREATED->ALIVE transition)
	// formaer rtc_init_entry()
	virtual RTC::ReturnCode_t onInitialize();

  // The finalize action (on ALIVE->END transition)
  // formaer rtc_exiting_entry()
  // virtual RTC::ReturnCode_t onFinalize();

  // The startup action when ExecutionContext startup
  // former rtc_starting_entry()
  // virtual RTC::ReturnCode_t onStartup(RTC::UniqueId ec_id);

  // The shutdown action when ExecutionContext stop
  // former rtc_stopping_entry()
  // virtual RTC::ReturnCode_t onShutdown(RTC::UniqueId ec_id);

	// The activated action (Active state entry action)
	// former rtc_active_entry()
	virtual RTC::ReturnCode_t onActivated(RTC::UniqueId ec_id);

	// The deactivated action (Active state exit action)
	// former rtc_active_exit()
	virtual RTC::ReturnCode_t onDeactivated(RTC::UniqueId ec_id);

	// The execution action that is invoked periodically
	// former rtc_active_do()
	virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);

  // The aborting action when main logic error occurred.
  // former rtc_aborting_entry()
  // virtual RTC::ReturnCode_t onAborting(RTC::UniqueId ec_id);

  // The error action in ERROR state
  // former rtc_error_do()
  // virtual RTC::ReturnCode_t onError(RTC::UniqueId ec_id);

  // The reset action that is invoked resetting
  // This is same but different the former rtc_init_entry()
  // virtual RTC::ReturnCode_t onReset(RTC::UniqueId ec_id);

  // The state update action that is invoked after onExecute() action
  // no corresponding operation exists in OpenRTm-aist-0.2.0
  // virtual RTC::ReturnCode_t onStateUpdate(RTC::UniqueId ec_id);

  // The action that is invoked when execution context's rate is changed
  // no corresponding operation exists in OpenRTm-aist-0.2.0
  // virtual RTC::ReturnCode_t onRateChanged(RTC::UniqueId ec_id);


 protected:
  // Configuration variable declaration
  // <rtc-template block="config_declare">
  double m_01_latitude;
  double m_02_longitude;
  double m_03_19x;
  double m_04_19y;
  double m_05_robotx;
  double m_06_roboty;
  
  // </rtc-template>

  // DataInPort declaration
  // <rtc-template block="inport_declare">
  
  // </rtc-template>

  // DataOutPort declaration
  // <rtc-template block="outport_declare">
  TimedJgd2000Position m_OutJgd2000Position;
  OutPort<TimedJgd2000Position> m_OutJgd2000PositionOut;
  Timed19Position m_Out19Position;
  OutPort<Timed19Position> m_Out19PositionOut;
  TimedRobotPosition m_OutRobotPosition;
  OutPort<TimedRobotPosition> m_OutRobotPositionOut;
  
  // </rtc-template>

  // CORBA Port declaration
  // <rtc-template block="corbaport_declare">
  
  // </rtc-template>

  // Service declaration
  // <rtc-template block="service_declare">
  
  // </rtc-template>

  // Consumer declaration
  // <rtc-template block="consumer_declare">
  
  // </rtc-template>

	private:
		int dummy;


		//-- [変数宣言] -----------------------------------------------------------------//

		double latitude;									// 緯度格納変数
		double longitude;									// 経度格納変数
		double x;										// 平面直角座標系x座標格納変数
		double y;										// 平面直角座標系y座標格納変数
		double robot_x;										// ロボット座標系x座標格納変数
		double robot_y;										// ロボット座標系y座標格納変数
		double timestamp;									// タイムスタンプ格納変数
		unsigned long sec;									// タイムスタンプ格納変数 [sec]
		unsigned long nsec;									// タイムスタンプ格納変数 [nsec]

		//-------------------------------------------------------------------------------//


};


extern "C"
{
  void TestInputInit(RTC::Manager* manager);
};

#endif // TESTINPUT_H
